<TS language="nl" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Over Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Maak een nieuw adres aan</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopieer het geselecteerde adres naar het klembord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopieer</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Toon &amp;QR Code</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Teken een bericht om te bewijzen dat je een Gridcoin adres bezit.</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Teken &amp;Bericht</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verifieer een bericht om zeker te zijn dat deze is ondertekend met een specifiek Gridcoin adres</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifieer Bericht</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Verwijder het geselecteerde adres van de lijst</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Adresboek</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Dit zijn al jou Gridcoin adressen om betalingen mee te ontvangen. Je kunt iedere verzender een apart adres geven zodat je kunt volgen wie jou betaald.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwijder</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopieer &amp;Label</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bewerk</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exporteer Adresboek Data</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Fout bij exporteren</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kan niet schrijven naat bestand %1</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Wachtwoorddialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Voer wachtwoord in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nieuw wachtwoord</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nieuw wachtwoord</translation>
    </message>
    <message>
        <source>Serves to disable the trivial sendmoney when OS account compromised. Provides no real security.</source>
        <translation>Bedoeld om het command 'sendmoney' uit te schakelen indien het OS niet meer veilig is. Geeft geen echte beveiliging.</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Alleen voor staking</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Voer een nieuw wachtwoord in voor uw portemonnee.&lt;br/&gt;Gebruik een wachtwoord van &lt;b&gt;tien of meer willekeurige karakters&lt;/b&gt;, of &lt;b&gt;acht of meer woorden&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Versleutel portemonnee</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Deze operatie vereist uw portemonneewachtwoord om de portemonnee te openen.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Open portemonnee</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Wijzig wachtwoord</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Vul uw oude en nieuwe portemonneewachtwoord in.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bevestig versleuteling van de portemonnee</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Waarschuwing: Als je je portemonnee versleuteld en je verliest je wachtwoord zul je &lt;b&gt;AL JE MUNTEN VERLIEZEN&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Weet u zeker dat u uw portemonnee wilt versleutelen?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portemonnee versleuteld</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin zal nu sluiten om het versleutel proces te voltooien. Onthou dat het versleutelen van je portemonnee je niet volledig beschermt tegen diefstal van munten door malware op je computer.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>BELANGRIJK: Elke eerder gemaakte backup van uw portemonneebestand dient u te vervangen door het nieuw gegenereerde, versleutelde portemonneebestand. Om veiligheidsredenen zullen eerdere backups van het niet-versleutelde portemonneebestand onbruikbaar worden zodra u uw nieuwe, versleutelde, portemonnee begint te gebruiken.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Portemonneeversleuteling mislukt</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Portemonneeversleuteling mislukt door een interne fout. Uw portemonnee is niet versleuteld.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>De opgegeven wachtwoorden komen niet overeen</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Portemonnee openen mislukt</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Het opgegeven wachtwoord voor de portemonnee-ontsleuteling is niet correct.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Portemonneewachtwoord is met succes gewijzigd.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Waarschuwing: De Caps-Lock-toets staat aan!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>A fatal error occurred. Gridcoin can no longer continue safely and will quit.</source>
        <translation>Een fatale fout . Gridcoin kan niet langer veilig doorgaan en sluit af.</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Portemonnee</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Overzicht</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Toon algemeen overzicht van uw portemonnee</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Verstuur</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Verstuur munten naar een Gridcoin adres</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ontvangen</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Toon de lijst  aan adressen voor ontvangen betalingen</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Blader door transactiegescheidenis</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Wijzig de lijst met bewaarde adressen en labels</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;fsluiten</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Programma afsluiten</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Over Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Toon informatie over Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opties...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Verander configuratie opties voor Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Toon / Verberg</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Versleutel Portemonnee...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Wijzig Wachtwoord</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Wijzig het wachtwoord voor uw portemonneversleuteling</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>Ontgrendel portemonnee...</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Open portemonnee</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Sluit portemonnee</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Sluit portemonnee</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Onderteken bericht...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifiëer bericht...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Exporteren...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exporteer de data in de huidige tab naar een bestand</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Debugscherm</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Open debugging en diagnostische console</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[testnetwerk]</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Bijgewerkt</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Aan het bijwerken...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Laatst ontvangen blok is gegenereerd op %1.</translation>
    </message>
    <message>
        <source>This transaction is over the size limit.  You can still send it for a fee of %1, which goes to the nodes that process your transaction and helps to support the network.  Do you want to pay the fee?</source>
        <translation>De grootte van deze transactie overschrijdt de limiet. U kan deze transactie laten uitvoeren voor een meerkost van %1, dewelke doorgestuurd wordt naar de nodes die uw transactie verwerken, alsook ter ondersteuning van het netwerk. Wil u deze meerkost betalen?</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Bevestig transactie kosten</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Verstuurde transactie</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Binnenkomende transactie</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI-behandeling</translation>
    </message>
    <message>
        <source>URI can not be parsed! This can be caused by an invalid Gridcoin address or malformed URI parameters.</source>
        <translation>URI kan niet ontleedt worden! Mogelijke oorzaken zijn een ongeldig Gridcoin adres of incorrecte URI parameters.</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Portemonnee is &lt;b&gt;versleuteld&lt;/b&gt; en momenteel &lt;b&gt;gesloten&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation>Backup Portemonnee</translation>
    </message>
    <message>
        <source>Wallet Data (*.dat)</source>
        <translation>Portemonnee bestanden (*.dat)</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Backup mislukt</translation>
    </message>
    <message>
        <source>There was an error trying to save the wallet data to the new location.</source>
        <translation>Er was een fout opgetreden bij het opslaan van de wallet data naar de nieuwe locatie.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Netwerkwaarschuwing</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Kwantiteit</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Transactiekosten:</translation>
    </message>
    <message>
        <source>Coin Control</source>
        <translation>Coin controle opties</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lage uitvoer:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Naheffing:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Wisselgeld:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bevestigingen</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestigd</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopieer adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transactie-ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer aantal</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer vergoeding</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na vergoeding</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopieer lage uitvoer</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer wijziging</translation>
    </message>
    <message>
        <source>DUST</source>
        <translation>STOF</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>This label turns red, if the transaction size is bigger than 10000 bytes.

 This means a fee of at least %1 per kb is required.

 Can vary +/- 1 Byte per input.</source>
        <translation>Dit label wordt rood, als de transactie grootte groter is dan 10000 bytes.&lt;br&gt;

Dit betekend een fee van minimaal %1 per kb is noodzakelijk.&lt;br&gt;

Kan varieren van +/- 1 Byte per invulling</translation>
    </message>
    <message>
        <source>This label turns red, if any recipient receives an amount smaller than %1.

 This means a fee of at least %2 is required. 

 Amounts below 0.546 times the minimum relay fee are shown as DUST.</source>
        <translation>Dit label wordt rood, als elke ontvanger ontvangt een bedrag dat kleiner is dan %1. 

Dit betekent dat een vergoeding van ten minste %2 is vereist. 

Bedragen onder 0.546 keer het minimum vergoeding worden weergegeven als DUST.</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Dit label wordt rood, als de verandering kleiner is dan %1.

Dit betekend dat een fee van %2 is vereist.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>wijzig van %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(wijzig)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Bewerk Adres</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Het label geassocieerd met deze notitie in het adresboek</translation>
    </message>
    <message>
        <source>The address associated with this address book entry. This can only be modified for sending addresses.</source>
        <translation>Het adres geassocieerd met deze notitie in het adresboek. Dit kan enkel aangepast worden bij verzend-adressen.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adres</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nieuw ontvangstadres</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nieuw verzendadres</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Bewerk ontvangstadres</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Bewerk verzendadres</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Gridcoin address.</source>
        <translation>Het ingevoerde adres "%1" is geen geldig Gridcoin adres.</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Het opgegeven adres "%1" bestaat al in uw adresboek.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kon de portemonnee niet openen.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Genereren nieuwe sleutel mislukt.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versie</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Gebruik:</translation>
    </message>
    <message>
        <source>command-line options</source>
        <translation>Commandoregel-opties</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Algemeen</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Netwerk</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Portmapping via &amp;UPnP</translation>
    </message>
    <message>
        <source>Automatically start Gridcoin after logging in to the system.</source>
        <translation>Automatisch starten van Gridcoin na inloggen van het systeem.</translation>
    </message>
    <message>
        <source>&amp;Start Gridcoin on system login</source>
        <translation>&amp;Start Gridcoin bij systeem aanmelding</translation>
    </message>
    <message>
        <source>Automatically open the Gridcoin client port on the router. This only works when your router supports UPnP and it is enabled.</source>
        <translation>De Gridcoin client poort automatisch openen op de router. Dit werkt alleen wanneer uw router UPnP ondersteunt en deze is ingeschakeld.</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. 127.0.0.1)</source>
        <translation>IP Adres van de proxy (bijv. 127.0.0.1)</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Poort:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Poort van de proxy (bijv. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimaliseer het venster in de plaats van de applicatie af te sluiten als het venster gesloten wordt. Wanneer deze optie aan staan, kan de applicatie alleen worden afgesloten door Afsluiten te kiezen in het menu.</translation>
    </message>
    <message>
        <source>The user interface language can be set here. This setting will take effect after restarting Gridcoin.</source>
        <translation>De user interface-taal kan hier ingesteld worden. Deze instelling word toegepast na Gridcoin opnieuw op te starten.</translation>
    </message>
    <message>
        <source>Whether to show Gridcoin addresses in the transaction list or not.</source>
        <translation>Gridcoin adressen in de transactielijst weergeven of niet</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>Toon a&amp;dressen in de transactielijst</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Scherm</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Toepassen</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Laat alleen een systeemvakicoon zien wanneer het venster geminimaliseerd is</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimaliseer naar het systeemvak in plaats van de taakbalk</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimaliseer bij sluiten van het venster</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Interface</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Taal &amp;Gebruikersinterface:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Eenheid om bedrag in te tonen:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Kies de standaardonderverdelingseenheid om weer te geven in uw programma, en voor het versturen van munten</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuleren</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standaard</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarschuwing</translation>
    </message>
    <message>
        <source>This setting will take effect after restarting Gridcoin.</source>
        <translation>Deze instelling word toegepast na een restart van Gridcoin.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Het opgegeven proxyadres is ongeldig.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Beschikbaar:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Uw beschikbare saldo</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Immatuur:</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Gridcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>De weergegeven informatie kan verouderd zijn, Je portemonnee synchroniseerd automatisch met het Gridcoin netwerk nadat er verbindig is gemaakt, maar dit proces is nog niet voltooid.</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the current balance</source>
        <translation>Totaal van de transacties die nog moeten worden bevestigd, en nog niet mee voor het huidige balans</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totaal:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Uw totale saldo</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>QR Code Dialog</source>
        <translation>QR Code Scherm</translation>
    </message>
    <message>
        <source>Request Payment</source>
        <translation>Vraag betaling</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Bericht:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Opslaan als...</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Fout tijdens encoderen URI in QR-code</translation>
    </message>
    <message>
        <source>The entered amount is invalid, please check.</source>
        <translation>De ingevoerde hoeveel is ongeldig, controleer aub.</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>Resulterende URI te lang, probeer de tekst korter te maken voor het label/bericht.</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>Sla QR Code op.</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>N.v.t.</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Clientversie</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informatie</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Opstarttijd</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Aantal connecties</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokketen</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Huidig aantal blokken</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Tijd laatste blok</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Wissen</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Netwerkverkeer</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totalen</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Uit:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Debuglogbestand</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Maak console leeg</translation>
    </message>
    <message>
        <source>On testnet</source>
        <translation>Op testnetwerk</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Geschat totaal aantal blokken</translation>
    </message>
    <message>
        <source>Open the Gridcoin debug log file from the current data directory. This can take a few seconds for large log files.</source>
        <translation>Open het Gridcoin debug log bestand van de huidige data map. Dit kan een paar seconden duren voor grote log bestanden.</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Commandoregel-opties</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Clientnaam</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Gebruik de pijltjestoetsen om door de geschiedenis te navigeren, en &lt;b&gt;Ctrl-L&lt;/b&gt; om het scherm leeg te maken.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Typ &lt;b&gt;help&lt;/b&gt; voor een overzicht van de beschikbare opdrachten.</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 Kb</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 Gb</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Verstuurde munten</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Invoer...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automatisch geselecteerd</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Onvoldoende fonds!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kwantiteit</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Kosten:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lage uitvoer:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Naheffing:</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Wijzigen</translation>
    </message>
    <message>
        <source>custom change address</source>
        <translation>handmatig veranderen adres</translation>
    </message>
    <message>
        <source>Remove all transaction fields</source>
        <translation>Verwijder alles in de invulvelden</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Verstuur in een keer aan verschillende ontvangers</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Voeg &amp;Ontvanger Toe</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Verwijder &amp;Alles</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Bevestig de verstuuractie</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>V&amp;erstuur</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer aantal</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer vergoeding</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na vergoeding</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer bytes</translation>
    </message>
    <message>
        <source>Copy low output</source>
        <translation>Kopieer lage uitvoer</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer wijziging</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; to %2 (%3)</source>
        <translation>&lt;b&gt; %1 &lt;/b&gt; to %2 (%3)</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Bevestig versturen munten</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Weet je zeker dat je %1 wilt verzenden?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>en</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Het ontvangstadres is niet geldig, controleer uw invoer.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Het ingevoerde bedrag moet groter zijn dan 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Het bedrag is hoger dan uw huidige saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Het totaal overschrijdt uw huidige saldo wanneer de %1 transactiekosten worden meegerekend.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Dubbel adres gevonden, u kunt slechts eenmaal naar een bepaald adres verzenden per verstuurtransactie</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed.</source>
        <translation>FOUT: Creëren van transactie mislukt.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected. This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Fout: De transactie was geweigerd, Dit kan gebeuren als sommige munten in je portemonnee al gebruikt zijn, door het gebruik van een kopie van wallet.dat en de munten in de kopie zijn niet gemarkeerd als gebruikt.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen label)</translation>
    </message>
    <message>
        <source>WARNING: Invalid Gridcoin address</source>
        <translation>WAARSCHUWING: Ongeldig Gridcoin adres</translation>
    </message>
    <message>
        <source>WARNING: unknown change address</source>
        <translation>WAARSCHUWING: Onbekend adres</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>B&amp;edrag:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Betaal &amp;Aan:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Bericht:</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Plak adres vanuit klembord</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Kies adres uit adresboek</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Verwijder deze ontvanger</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Vul een label in voor dit adres om het toe te voegen aan uw adresboek</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Handtekeningen – Onderteken een bericht / Verifiëer een handtekening</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Onderteken Bericht</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>U kunt berichten ondertekenen met een van uw adressen om te bewijzen dat u dit adres bezit. Pas op dat u geen onduidelijke dingen ondertekent, want phishingaanvallen zouden u kunnen misleiden om zo uw identiteit te stelen. Onderteken alleen berichten waarmee u het volledig eens bent.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Kies een adres uit het adresboek</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Plak adres vanuit klembord</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Typ hier het bericht dat u wilt ondertekenen</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopieer de huidige handtekening naar het systeemklembord</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Gridcoin address</source>
        <translation>Teken een bericht om te bewijzen dat je een Gridcoin adres bezit.</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Onderteken &amp;Bericht</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Verwijder alles in de invulvelden</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Verwijder &amp;Alles</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifiëer Bericht</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Voer het ondertekenende adres, bericht en handtekening hieronder in (let erop dat u nieuwe regels, spaties en tabs juist overneemt) om de handtekening te verifiëren. Let erop dat u niet meer uit het bericht interpreteert dan er daadwerkelijk staat,  om te voorkomen dat u wordt misleid in een man-in-the-middle-aanval.</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Gridcoin address</source>
        <translation>Verifieer een bericht om zeker te zijn dat deze is ondertekend met een specifiek Gridcoin adres</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Verwijder alles in de invulvelden</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klik op "Onderteken Bericht" om de handtekening te genereren</translation>
    </message>
    <message>
        <source>Enter Gridcoin signature</source>
        <translation>Voer Gridcoin handtekening in</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Het opgegeven adres is ongeldig.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Controleer het adres en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Het opgegeven adres verwijst niet naar een sleutel.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Portemonnee-ontsleuteling is geannuleerd.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Geheime sleutel voor het ingevoerde adres is niet beschikbaar.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Ondertekenen van het bericht is mislukt.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Bericht ondertekend.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>De handtekening kon niet worden gedecodeerd.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Controleer de handtekening en probeer het opnieuw.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>De handtekening hoort niet bij het bericht.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Berichtverificatie mislukt.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Bericht geverifiëerd.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Open tot %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/onbevestigd</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 bevestigingen</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, is nog niet met succes uitgezonden</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Bron</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Van</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Aan</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>eigen adres</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>niet geaccepteerd</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transactiekosten</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Netto bedrag</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Bericht</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>true</source>
        <translation>waar</translation>
    </message>
    <message>
        <source>false</source>
        <translation>onwaar</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transactiedetails</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Dit venster laat een uitgebreide beschrijving van de transactie zien</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Open tot %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Onbevestigd</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Bevestigd (%1 bevestigingen)</translation>
    </message>
    <message>
        <source>Conflicted</source>
        <translation>Conflicterend</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Gegenereerd maar niet geaccepteerd</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvangen met</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ontvangen van</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Verzonden aan</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Betaling aan uzelf</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(nvt)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transactiestatus. Houd de cursor boven dit veld om het aantal bevestigingen te laten zien.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum en tijd waarop deze transactie is ontvangen.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Type transactie.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Ontvangend adres van transactie.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Bedrag verwijderd van of toegevoegd aan saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Vandaag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Deze week</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Deze maand</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Vorige maand</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Dit jaar</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Bereik...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvangen met</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Verzonden aan</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Aan uzelf</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gedolven</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Anders</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min. bedrag</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopieer adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer label</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transactie-ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Bewerk label</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Toon transactiedetails</translation>
    </message>
    <message>
        <source>Export Transaction Data</source>
        <translation>Exporteer Transactie Data</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestigd</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Fout bij exporteren</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kan niet schrijven naar bestand %1</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Bereik:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>naar</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Versturen...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Er is een fout opgetreden tijdens het instellen van de inkomende RPC-poort %u op IPv6, terugval naar IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Er is een fout opgetreden tijdens het instellen van de inkomende RPC-poort %u op IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Gebruik:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Lijst van commando's</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Toon hulp voor een commando</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Waarschuwing: -paytxfee is zeer hoog ingesteld.  Dit zijn de transactiekosten die u betaalt bij het versturen van een transactie.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Waarschuwing: wallet.dat is corrupt, data is veiliggesteld! Originele wallet.dat is opgeslagen als wallet.{tijdstip}.bak in %s; als uw balans of transacties incorrect zijn dient u een backup terug te zetten.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Waarschuwing: Fout bij het lezen van wallet.dat! Alle sleutels zijn in goede orde uitgelezen, maar transactiedata of adresboeklemma's zouden kunnen ontbreken of fouten bevatten.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Fout: Creëren van transactie mislukt.</translation>
    </message>
    <message>
        <source>Error: The transaction was rejected.  This might happen if some of the coins in your wallet were already spent, such as if you used a copy of wallet.dat and coins were spent in the copy but not marked as spent here.</source>
        <translation>Fout: De transactie was geweigerd, Dit kan gebeuren als sommige munten in je portemonnee al gebruikt zijn, door het gebruik van een kopie van wallet.dat en de munten in de kopie zijn niet gemarkeerd als gebruikt.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Mislukt om op welke poort dan ook te luisteren. Gebruik -listen=0 as u dit wilt.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Om de %s optie te gebruiken</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>U dient rpcpassword=&lt;wachtwoord&gt; in te stellen in het configuratiebestand:
%s
Als het bestand niet bestaat, maak het dan aan, met een alleen-lezen permissie.</translation>
    </message>
    <message>
        <source>Gridcoin version</source>
        <translation>Gridcoin versie</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Ongeldig bedrag voor -paytxfee=&lt;bedrag&gt;: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -mininput=&lt;amount&gt;: '%s'</source>
        <translation>Ongeldig bedrag voor -mininput = &lt;bedrag&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Portemonnee %s bevindt zich buiten de datamap %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Database integriteit wordt geverifieërd</translation>
    </message>
    <message>
        <source>Error initializing database environment %s! To recover, BACKUP THAT DIRECTORY, then remove everything from it except for wallet.dat.</source>
        <translation>Fout bij het ??initialiseren van de database omgeving %s! Om te herstellen, BACKUP die directory, verwijder dan alles van behalve het wallet.dat.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrupt, veiligstellen mislukt</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Ongeldig -proxy adres: '%s'</translation>
    </message>
    <message>
        <source>Invalid -tor address: '%s'</source>
        <translation>Ongeldig-tor adres: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Kan -bind adres niet herleiden: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Kan -externlip adres niet herleiden: '%s'</translation>
    </message>
    <message>
        <source>Invalid amount for -reservebalance=&lt;amount&gt;</source>
        <translation>Ongeldig bedrag voor -reservebalance = &lt;bedrag&gt;</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Fout bij laden van blkindex.dat</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Fout bij laden wallet.dat: Portemonnee corrupt</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Fout bij laden van wallet.dat: Portemonnee vereist een nieuwere versie van Gridcoin</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Portemonnee moet herschreven worden: herstart Gridcoin om te voltooien</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Fout bij laden wallet.dat</translation>
    </message>
    <message>
        <source>Importing bootstrap blockchain data file.</source>
        <translation>Importeren van blokketen data bestand.</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Adressen aan het laden...</translation>
    </message>
    <message>
        <source>Error: could not start node</source>
        <translation>Fout: kan geen verbinding maken met node</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer. Gridcoin is probably already running.</source>
        <translation>Niet mogelijk om %s op deze computer. Gridcoin is waarschijnlijk al geopened.</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Niet in staat om aan %s te binden op deze computer (bind gaf error %d, %s)</translation>
    </message>
    <message>
        <source>Error: Wallet locked, unable to create transaction  </source>
        <translation>Fout: Portemonnee is op slot, niet mogelijk een transactie te creëren.</translation>
    </message>
    <message>
        <source>Error: Wallet unlocked for staking only, unable to create transaction.</source>
        <translation>Fout: Portemonnee ontgrendeld voor alleen staking, niet in staat om de transactie te maken.</translation>
    </message>
    <message>
        <source>Error: This transaction requires a transaction fee of at least %s because of its amount, complexity, or use of recently received funds  </source>
        <translation>Fout: Deze transactie vereist een transactie vergoeding van ten minste %s vanwege de hoeveelheid, complexiteit, of het gebruik van recent ontvangen gelden</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Versturen...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Ongeldig bedrag</translation>
    </message>
    <message>
        <source>Warning: Please check that your computer's date and time are correct! If your clock is wrong Gridcoin will not work properly.</source>
        <translation>Waarschuwing: Controleer of de datum en tijd van de computer juist zijn! Als uw klok verkeerd is Gridcoin zal niet goed werken.</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Waarschuwing: Hardeschijf raakt vol!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Onbekend netwerk gespecificeerd in -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Ontoereikend saldo</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Blokindex aan het laden...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Portemonnee aan het laden...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Kan standaardadres niet schrijven</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Blokketen aan het herscannen...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Klaar met laden</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>